@@ -49,7 +49,7 @@ class Num2Word_PT_BR(lang_PT.Num2Word_PT):
             if nnum < 1000000:
                 return next
             ctext = "um"
-        elif cnum == 100 and not nnum == 1000:
+        elif cnum == 100 and nnum % 1000 != 0:
             ctext = "cento"
 
         if nnum < cnum:
@@ -77,7 +77,7 @@ class Num2Word_PT_BR(lang_PT.Num2Word_PT):
         for ext in (
                 'mil', 'milhão', 'milhões', 'bilhão', 'bilhões',
                 'trilhão', 'trilhões', 'quatrilhão', 'quatrilhões'):
-            if re.match('.*{} e \\w*ento'.format(ext), result):
+            if re.match('.*{} e \\w*entos? (?=.*e)'.format(ext), result):
                 result = result.replace(
                     '{} e'.format(ext), '{},'.format(ext), 1
                 )
